@@ -37,6 +37,7 @@ class IoTStorageClientAsync:
     module: Optional[str] = None
     host: Optional[str] = None
     port: Optional[str] = None
+    private: Optional[bool] = False
 
     service_client: BlobServiceClient
     container_client: ContainerClient
@@ -51,6 +52,7 @@ class IoTStorageClientAsync:
         module: Optional[str] = None,
         host: Optional[str] = None,
         port: Optional[str] = None,
+        private: Optional[bool] = False,
     ) -> None:
         self.credential_type = credential_type
         self.location_type = location_type
@@ -59,6 +61,7 @@ class IoTStorageClientAsync:
         self.module = module
         self.host = host
         self.port = port
+        self.private = private
         self.instantiate_service_client()
 
     def __repr__(self) -> str:
@@ -82,6 +85,7 @@ class IoTStorageClientAsync:
             if self.location_type == LocationType.CLOUD_BASED:
                 connection_string = generate_cloud_conn_str(
                     account=self.account_name,
+                    private=self.private,
                     account_key=self.credential
                     if self.credential_type == CredentialType.ACCOUNT_KEY
                     else None,
@@ -520,6 +524,7 @@ class IoTStorageClientAsync:
                     return generate_cloud_sas_url(
                         account=self.account_name,
                         account_sas=sas_token,
+                        private=self.private,
                         blob_path=f"{container_name}/{source}",
                     )
                 if self.location_type == LocationType.EDGE_BASED:
@@ -528,6 +533,7 @@ class IoTStorageClientAsync:
                         port=self.port,
                         account=self.account_name,
                         account_sas=sas_token,
+                        private=self.private,
                         blob_path=f"{container_name}/{source}",
                     )
                 if self.location_type == LocationType.LOCAL_BASED:
@@ -536,6 +542,7 @@ class IoTStorageClientAsync:
                         port=self.port,
                         account=self.account_name,
                         account_sas=sas_token,
+                        private=self.private,
                         blob_path=f"{container_name}/{source}",
                     )
                 return None
@@ -583,6 +590,7 @@ class IoTStorageClientAsync:
                     return generate_cloud_sas_url(
                         account=self.account_name,
                         account_sas=sas_token,
+                        private=self.private,
                         blob_path=container_name,
                     )
                 if self.location_type == LocationType.EDGE_BASED:
@@ -591,6 +599,7 @@ class IoTStorageClientAsync:
                         port=self.port,
                         account=self.account_name,
                         account_sas=sas_token,
+                        private=self.private,
                         blob_path=container_name,
                     )
                 if self.location_type == LocationType.LOCAL_BASED:
@@ -599,6 +608,7 @@ class IoTStorageClientAsync:
                         port=self.port,
                         account=self.account_name,
                         account_sas=sas_token,
+                        private=self.private,
                         blob_path=container_name,
                     )
                 return None
